#
# spec file for package paps
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           paps
Version:        0.8.0
Release:        1.1
Summary:        A text to postscript converter through pango
License:        LGPL-2.0-only
Group:          System/Base
URL:            https://github.com/dov/%{name}
Source:         https://github.com/dov/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         paps-header_features.patch
Patch1:         71.patch
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  rpm_macro(meson)
Requires:       glibc-locale

%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}

%description
paps is a command line program for converting Unicode text encoded in UTF-8 to postscript and pdf by using pango.

%prep
%setup -qT -b0 -n %{name}-%{version}
%patch -P 0 -p0 -b .p0
%patch -P 1 -p1 -b .p1

%build
%add_optflags -D_XOPEN_SOURCE
%meson
%meson_build

%install
%meson_install

%files
%defattr(-,root,root)
%license COPYING.LIB
%{_bindir}/*
%{_mandir}/*/*
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/pango_markup.outlang

%changelog
* Wed Sep 18 2024 Dr. Werner Fink <werner@suse.de>
- Update to paps 0.8.0
  * Fixed minor bugs from 0.7.9
  * Fixed bug when using markup with char mapping and visible wrap marker.
  * Added src-to-paps preprocessor scripts for conversion of source code
    to paps through GNU Highlight.
  * Switch to C++17
  * The header and footers are now modifiable by a syntax borrowed from
    python and the fmt library. E.g. the following command line shows
    what is possible:
    paps --header-left="{now:%%Y-%%m-%%d %%H:%%M}" --header-center="{path}" \
  - -header-right="Page {page_idx:02d}/{num_pages:02d}" --header -o hello.pdf paps.cc
  * Add separation line option
- Remove patches now upstream
  * paps-cpi_scale_calculation.patch
  * paps-glib.patch
  * paps-gutter-width.patch
  * paps-layout.patch
  * paps-manpage_fixes.patch
  * paps-manpage_units.patch
  * paps-page_setup.patch
- Port patch paps-header_features.patch
- Add 71.patch to fix build with glib 2.82
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Feb  7 2022 Dr. Werner Fink <werner@suse.de>
- For iconv glibc-locale should be installed
* Fri Dec  4 2020 Dr. Werner Fink <werner@suse.de>
- Add patch paps-header_features.patch which combines three
  patches to be able to change header font, date, and rule
  thickness
* Wed Oct  7 2020 Dr. Werner Fink <werner@suse.de>
- Update to paps 0.7.1
  * Added initial meson compilation support.
  * Minor accumulated bug fixes since 0.7.0
- Drop patch paps-prog_cc_c_o.patch as now solved upstream
* Mon May 13 2019 Dr. Werner Fink <werner@suse.de>
- Add patch paps-glib.patch to amke it build again ... seems to be
  a problem with the actuial linker as it ignores dependencies of
  the already specified libraries.
* Tue Dec  5 2017 werner@suse.de
- Add patch paps-layout.patch as a try to get page layout to
  something useful
* Tue Dec  5 2017 werner@suse.de
- Initial version paps from https://github.com/dov/paps master (was 37e6ca1)
- Add patches
    paps-prog_cc_c_o.patch to silent auto tools
    paps-cpi_scale_calculation.patch avoid possible miscalculated scale
    paps-manpage_units.patch make clear we are using points
    paps-manpage_fixes.patch for better understanding
    paps-gutter-width.patch enable to set gutter when printing multiple columns
    paps-page_setup.patch help modern PS viewers with page setup
